@@ -1,4 +1,4 @@
-// $Revision: #5 $$Date: 2004/01/27 $$Author: wsnyder $ -*- SystemC -*-
+// $Revision: #6 $$Date: 2004/07/19 $$Author: ws150726 $ -*- SystemC -*-
 //=============================================================================
 //
 // THIS MODULE IS PUBLICLY LICENSED
@@ -31,7 +31,13 @@
 //=============================================================================
 // SpCoverage
 
-// The user is expected to declare this function's implementation themself
-extern void sp_coverage_data (const char *hier, const char *what, const char *file, int lineno, uint32_t data);
+class SpCoverage {
+public:
+    // GLOBAL METHODS
+    // Write all coverage data to a file
+    static void write (const char* filename = "logs/coverage.pl");
+    // Called by write lower-level routines to log a single coverage statistic
+    static void data (const char* hier, const char* what, const char* file, int lineno, const char* cmt, uint32_t data);
+};
 
 #endif // guard
